@@ -2,6 +2,7 @@ import os
 import sys
 import datetime
 import ctypes
+from ctypes import wintypes
 import random
 
 from sty import bg, fg, rs
@@ -33,6 +34,24 @@ class CONSOLE_FONT_INFOEX(ctypes.Structure):
     ]
 
 
+class CONSOLE_SCREEN_BUFFER_INFOEX(ctypes.Structure):
+    _fields_ = (
+        ("cbSize", wintypes.ULONG),
+        ("dwSize", COORD),
+        ("dwCursorPosition", COORD),
+        ("wAttributes", wintypes.WORD),
+        ("srWindow", wintypes.SMALL_RECT),
+        ("dwMaximumWindowSize", COORD),
+        ("wPopupAttributes", wintypes.WORD),
+        ("bFullscreenSupported", wintypes.BOOL),
+        ("ColorTable", wintypes.DWORD * 16),
+    )
+
+    def __init__(self, *args, **kwds):
+        super(CONSOLE_SCREEN_BUFFER_INFOEX, self).__init__(*args, **kwds)
+        self.cbSize = ctypes.sizeof(self)
+
+
 def exception_handler(func):
     def inner_function(*args, **kwargs):
         try:
@@ -77,6 +96,29 @@ class ConsoleMaster:
             flush=True,
         )
 
+    @exception_handler
+    def change_console_color(self, background_color, foreground_color):
+        console_handle = ctypes.windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
+        console_screen_information = CONSOLE_SCREEN_BUFFER_INFOEX()
+        ctypes.windll.kernel32.GetConsoleScreenBufferInfoEx(
+            console_handle, ctypes.byref(console_screen_information)
+        )
+        console_screen_information.srWindow.Bottom += 1
+        console_screen_information.ColorTable[0] = (
+            background_color[0]
+            + (background_color[1] * 256)
+            + (background_color[2] * 256 * 256)
+        )
+        console_screen_information.ColorTable[7] = (
+            foreground_color[0]
+            + (foreground_color[1] * 256)
+            + (foreground_color[2] * 256 * 256)
+        )
+        ctypes.windll.kernel32.SetConsoleScreenBufferInfoEx(
+            console_handle, ctypes.byref(console_screen_information)
+        )
+        os.system("cls")
+
     @exception_handler
     def go_xy(self, x, y):
         INIT_POS = COORD(x, y)
